==> jc-1.4.0.tar.gz: ppg/atoms/GrammarSymbol.h <==
// public abstract class ppg.atoms.GrammarSymbol

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart
// @dep_class 27d4aedc7c66ddea ppg_atoms_GrammarSymbol

// header file dependencies
// @dep_header ppg_atoms_GrammarPart

#include "ppg/atoms/GrammarPart.h"

#ifndef _JC_ppg_atoms_GrammarSymbol_H_
#define _JC_ppg_atoms_GrammarSymbol_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_atoms_GrammarSymbol$sub_refs	_jc_ppg_atoms_GrammarSymbol$sub_refs;
typedef struct _jc_ppg_atoms_GrammarSymbol$sub_nonrefs	_jc_ppg_atoms_GrammarSymbol$sub_nonrefs;
typedef struct _jc_ppg_atoms_GrammarSymbol$refs	_jc_ppg_atoms_GrammarSymbol$refs;
typedef struct _jc_ppg_atoms_GrammarSymbol$nonrefs	_jc_ppg_atoms_GrammarSymbol$nonrefs;
typedef struct _jc_ppg_atoms_GrammarSymbol$object	_jc_ppg_atoms_GrammarSymbol$object;

typedef const struct _jc_ppg_atoms_GrammarSymbol$vmethods	_jc_ppg_atoms_GrammarSymbol$vmethods;
typedef const struct _jc_ppg_atoms_GrammarSymbol$vtable	_jc_ppg_atoms_GrammarSymbol$vtable;
typedef const struct _jc_ppg_atoms_GrammarSymbol$vtype	_jc_ppg_atoms_GrammarSymbol$vtype;

// Constructors
extern void _jc_ppg_atoms_GrammarSymbol$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_GrammarSymbol$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_GrammarSymbol$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *);
extern void _jc_ppg_atoms_GrammarSymbol$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *, struct _jc_ppg_util_CodeWriter$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_GrammarSymbol$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_ppg_atoms_GrammarSymbol$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_ppg_atoms_GrammarSymbol$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_atoms_GrammarSymbol$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *);
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *, struct _jc_ppg_util_CodeWriter$object *);
};

// Vtable
struct _jc_ppg_atoms_GrammarSymbol$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_GrammarPart$vmethods	ppg_atoms_GrammarPart;
	_jc_ppg_atoms_GrammarSymbol$vmethods	ppg_atoms_GrammarSymbol;
};

// Vtype
struct _jc_ppg_atoms_GrammarSymbol$vtype {
	_jc_type			type;
	_jc_ppg_atoms_GrammarSymbol$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_GrammarSymbol$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*label;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_GrammarSymbol$refs {
    _jc_ppg_atoms_GrammarSymbol$sub_refs	ppg_atoms_GrammarSymbol;
    _jc_ppg_atoms_GrammarPart$sub_refs	ppg_atoms_GrammarPart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_GrammarSymbol$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_GrammarSymbol$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_GrammarPart$sub_nonrefs	ppg_atoms_GrammarPart;
    _jc_ppg_atoms_GrammarSymbol$sub_nonrefs	ppg_atoms_GrammarSymbol;
};

// Object instance structure
struct _jc_ppg_atoms_GrammarSymbol$object {
	_jc_ppg_atoms_GrammarSymbol$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_GrammarSymbol$vtype	*vtype;
	_jc_ppg_atoms_GrammarSymbol$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_GrammarSymbol$vtype _jc_ppg_atoms_GrammarSymbol$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_GrammarSymbol, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_GrammarSymbol$class_object;

#endif	/* _JC_ppg_atoms_GrammarSymbol_H_ */

==> jc-1.4.6.tar.gz: ppg/atoms/GrammarSymbol.h <==
// public abstract class ppg.atoms.GrammarSymbol

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart
// @dep_class 27d4aedc7c66ddea ppg_atoms_GrammarSymbol

// header file dependencies
// @dep_header ppg_atoms_GrammarPart

#include "ppg/atoms/GrammarPart.h"

#ifndef _JC_ppg_atoms_GrammarSymbol_H_
#define _JC_ppg_atoms_GrammarSymbol_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_atoms_GrammarSymbol$sub_refs	_jc_ppg_atoms_GrammarSymbol$sub_refs;
typedef struct _jc_ppg_atoms_GrammarSymbol$sub_nonrefs	_jc_ppg_atoms_GrammarSymbol$sub_nonrefs;
typedef struct _jc_ppg_atoms_GrammarSymbol$refs	_jc_ppg_atoms_GrammarSymbol$refs;
typedef struct _jc_ppg_atoms_GrammarSymbol$nonrefs	_jc_ppg_atoms_GrammarSymbol$nonrefs;
typedef struct _jc_ppg_atoms_GrammarSymbol$object	_jc_ppg_atoms_GrammarSymbol$object;

typedef const struct _jc_ppg_atoms_GrammarSymbol$vmethods	_jc_ppg_atoms_GrammarSymbol$vmethods;
typedef const struct _jc_ppg_atoms_GrammarSymbol$vtable	_jc_ppg_atoms_GrammarSymbol$vtable;
typedef const struct _jc_ppg_atoms_GrammarSymbol$vtype	_jc_ppg_atoms_GrammarSymbol$vtype;

// Constructors
extern void _jc_ppg_atoms_GrammarSymbol$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_GrammarSymbol$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_GrammarSymbol$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_atoms_GrammarSymbol$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_GrammarSymbol$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_ppg_atoms_GrammarSymbol$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_ppg_atoms_GrammarSymbol$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_atoms_GrammarSymbol$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *) _JC_JCNI_ATTR;
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_atoms_GrammarSymbol$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_atoms_GrammarSymbol$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_GrammarPart$vmethods	ppg_atoms_GrammarPart;
	_jc_ppg_atoms_GrammarSymbol$vmethods	ppg_atoms_GrammarSymbol;
};

// Vtype
struct _jc_ppg_atoms_GrammarSymbol$vtype {
	_jc_type			type;
	_jc_ppg_atoms_GrammarSymbol$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_GrammarSymbol$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*label;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_GrammarSymbol$refs {
    _jc_ppg_atoms_GrammarSymbol$sub_refs	ppg_atoms_GrammarSymbol;
    _jc_ppg_atoms_GrammarPart$sub_refs	ppg_atoms_GrammarPart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_GrammarSymbol$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_GrammarSymbol$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_GrammarPart$sub_nonrefs	ppg_atoms_GrammarPart;
    _jc_ppg_atoms_GrammarSymbol$sub_nonrefs	ppg_atoms_GrammarSymbol;
};

// Object instance structure
struct _jc_ppg_atoms_GrammarSymbol$object {
	_jc_ppg_atoms_GrammarSymbol$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_GrammarSymbol$vtype	*vtype;
	_jc_ppg_atoms_GrammarSymbol$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_GrammarSymbol$vtype _jc_ppg_atoms_GrammarSymbol$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_GrammarSymbol, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_GrammarSymbol$class_object;

#endif	/* _JC_ppg_atoms_GrammarSymbol_H_ */
